@@ -25,19 +25,21 @@ die "Usage: perl $0 --model='Modular' [--patch='Simple 001' --patch='Simple 002'
 $opt{config} ||= "eg/$model.yaml";
 die "Invalid model config\n" unless -e $opt{config};
 
-my $synth = Synth::Config->new(model => $model);
+my $synth = Synth::Config->new(
+    model => $model,
+#    verbose => 1,
+);
 
 my $patches = $synth->import_yaml(
     file => $opt{config},
-    $opt{patch} ? (patches => $opt{patch}) : (),
+    defined $opt{patch} ? (patches => $opt{patch}) : (),
 );
 
-for my $patch (@$patches) {
-    my $settings = $synth->search_settings(name => $patch);
+for my $patch_name (@$patches) {
+    my $settings = $synth->search_settings(name => $patch_name);
     $synth->graphviz(
         settings   => $settings,
         model_name => $model,
-        patch_name => $patch,
         render     => 1,
     );
 }
